@@ -2,20 +2,21 @@
 
 This file is part of the physbiblio package.
 """
-import sys
-import traceback
 import ast
-from collections import OrderedDict
 import logging
 import logging.handlers
 import os
+import sys
+import traceback
+from collections import OrderedDict
+
 import six
 from appdirs import AppDirs
 
 try:
     from physbiblio.databaseCore import PhysBiblioDBCore, PhysBiblioDBSub
-    from physbiblio.tablesDef import profilesSettingsTable, searchesTable, tableFields
     from physbiblio.strings.main import ConfigStrings as cstr
+    from physbiblio.tablesDef import profilesSettingsTable, searchesTable, tableFields
 except ImportError:
     print("Could not find physbiblio and its modules!")
     print(traceback.format_exc())
@@ -32,7 +33,7 @@ class ConfigParameter:
 
     def __init__(self, name, default, description="", special=None, isGlobal=False):
         """Store the passed properties
-        
+
         Parameters:
             name: the parameter name in the database
             default: the default value if not edited by the user
@@ -63,12 +64,12 @@ class ConfigParameter:
 
 
 class ConfigParametersList(OrderedDict):
-    """Inherit from OrderedDict, but add a quick method to add 
+    """Inherit from OrderedDict, but add a quick method to add
     `ConfigParameter`s to the list"""
 
     def add(self, cp):
         """Add a new value, corresponding to the key that is cp.name
-        
+
         Parameters:
             cp: a ConfigParameter instance
         """
@@ -82,31 +83,57 @@ class ConfigParametersList(OrderedDict):
 configuration_params = ConfigParametersList()
 configuration_params.add(
     ConfigParameter(
-        "mainDatabaseName", "PBDATAphysbiblio.db", description=cstr.Desc.mainDBName,
-    )
-)
-configuration_params.add(
-    ConfigParameter("loggingLevel", 1, description=cstr.Desc.logLevel, special="int",)
-)
-configuration_params.add(
-    ConfigParameter(
-        "logFileName", "PBDATAparams.log", description=cstr.Desc.logFName, special=None,
+        "mainDatabaseName",
+        "PBDATAphysbiblio.db",
+        description=cstr.Desc.mainDBName,
     )
 )
 configuration_params.add(
     ConfigParameter(
-        "pdfFolder", "PBDATApdf", description=cstr.Desc.PDFFolder, special=None,
+        "loggingLevel",
+        1,
+        description=cstr.Desc.logLevel,
+        special="int",
     )
 )
 configuration_params.add(
-    ConfigParameter("pdfApplication", "", description=cstr.Desc.PDFApp, special=None,)
-)
-configuration_params.add(
-    ConfigParameter("webApplication", "", description=cstr.Desc.webApp, special=None,)
+    ConfigParameter(
+        "logFileName",
+        "PBDATAparams.log",
+        description=cstr.Desc.logFName,
+        special=None,
+    )
 )
 configuration_params.add(
     ConfigParameter(
-        "timeoutWebSearch", 20.0, description=cstr.Desc.timeout, special="float",
+        "pdfFolder",
+        "PBDATApdf",
+        description=cstr.Desc.PDFFolder,
+        special=None,
+    )
+)
+configuration_params.add(
+    ConfigParameter(
+        "pdfApplication",
+        "",
+        description=cstr.Desc.PDFApp,
+        special=None,
+    )
+)
+configuration_params.add(
+    ConfigParameter(
+        "webApplication",
+        "",
+        description=cstr.Desc.webApp,
+        special=None,
+    )
+)
+configuration_params.add(
+    ConfigParameter(
+        "timeoutWebSearch",
+        20.0,
+        description=cstr.Desc.timeout,
+        special="float",
     )
 )
 configuration_params.add(
@@ -116,42 +143,66 @@ configuration_params.add(
 )
 configuration_params.add(
     ConfigParameter(
-        "defaultLimitBibtexs", 100, description=cstr.Desc.limitBibtexs, special="int",
+        "defaultLimitBibtexs",
+        100,
+        description=cstr.Desc.limitBibtexs,
+        special="int",
     )
 )
 configuration_params.add(
     ConfigParameter(
-        "defaultUpdateFrom", 0, description=cstr.Desc.updateFrom, special="int",
+        "defaultUpdateFrom",
+        0,
+        description=cstr.Desc.updateFrom,
+        special="int",
     )
 )
 configuration_params.add(
     ConfigParameter(
-        "maxAuthorNames", 3, description=cstr.Desc.maxAuthorsD, special="int",
+        "maxAuthorNames",
+        3,
+        description=cstr.Desc.maxAuthorsD,
+        special="int",
     )
 )
 configuration_params.add(
     ConfigParameter(
-        "maxAuthorSave", 6, description=cstr.Desc.maxAuthorsS, special="int",
+        "maxAuthorSave",
+        6,
+        description=cstr.Desc.maxAuthorsS,
+        special="int",
     )
 )
 configuration_params.add(
     ConfigParameter(
-        "maxExternalAPIResults", 10, description=cstr.Desc.maxAPIRes, special="int",
+        "maxExternalAPIResults",
+        10,
+        description=cstr.Desc.maxAPIRes,
+        special="int",
     )
 )
 configuration_params.add(
     ConfigParameter(
-        "fetchAbstract", False, description=cstr.Desc.fetchAbstract, special="boolean",
+        "fetchAbstract",
+        False,
+        description=cstr.Desc.fetchAbstract,
+        special="boolean",
     )
 )
 configuration_params.add(
     ConfigParameter(
-        "defaultCategories", [], description=cstr.Desc.defaultCat, special="list",
+        "defaultCategories",
+        [],
+        description=cstr.Desc.defaultCat,
+        special="list",
     )
 )
 configuration_params.add(
     ConfigParameter(
-        "bibListFontSize", 9, description=cstr.Desc.fontSize, special="float",
+        "bibListFontSize",
+        9,
+        description=cstr.Desc.fontSize,
+        special="float",
     )
 )
 configuration_params.add(
@@ -175,16 +226,27 @@ configuration_params.add(
 )
 configuration_params.add(
     ConfigParameter(
-        "resizeTable", True, description=cstr.Desc.autoResize, special="boolean",
+        "resizeTable",
+        True,
+        description=cstr.Desc.autoResize,
+        special="boolean",
     )
 )
 configuration_params.add(
     ConfigParameter(
-        "maxSavedSearches", 5, description=cstr.Desc.maxSavedSearches, special="int",
+        "maxSavedSearches",
+        5,
+        description=cstr.Desc.maxSavedSearches,
+        special="int",
     )
 )
 configuration_params.add(
-    ConfigParameter("ADSToken", "", description=cstr.Desc.ADSToken, special=None,)
+    ConfigParameter(
+        "ADSToken",
+        "",
+        description=cstr.Desc.ADSToken,
+        special=None,
+    )
 )
 configuration_params.add(
     ConfigParameter(
@@ -790,8 +852,12 @@ class ConfigVars:
     adsUrl = "https://ui.adsabs.harvard.edu/abs/"
     arxivUrl = "https://arxiv.org"
     doiUrl = "https://doi.org/"
-    inspireRecord = "https://old.inspirehep.net/record/"
-    inspireSearchBase = "https://old.inspirehep.net/search"
+    inspireAPI = "https://inspirehep.net/api/"
+    inspireConferencesAPI = "https://inspirehep.net/api/conferences/"
+    inspireExperimentsLink = "https://inspirehep.net/experiments/"
+    inspireLiteratureAPI = "https://inspirehep.net/api/literature/"
+    inspireLiteratureLink = "https://inspirehep.net/literature/"
+    inspireOAI = "https://old.inspirehep.net/oai2d"
 
     def __init__(self, profileFileName="profiles.db"):
         """Initialize the configuration.
@@ -1017,7 +1083,7 @@ class ConfigVars:
             var: the input variable
 
         Output:
-            the input variable or a string with replaced "PBDATA" 
+            the input variable or a string with replaced "PBDATA"
         """
         if isinstance(var, six.string_types) and "PBDATA" in var:
             var = os.path.join(self.dataPath, var.replace("PBDATA", ""))
