@@ -3,8 +3,9 @@ that manage the some dialog windows.
 
 This file is part of the physbiblio package.
 """
-import traceback
 import ast
+import traceback
+
 import six
 from PySide2.QtCore import Qt, Signal
 from PySide2.QtGui import QTextCursor
@@ -23,11 +24,10 @@ from PySide2.QtWidgets import (
 )
 
 try:
-    from physbiblio.config import pbConfig, configuration_params
-    from physbiblio.errors import pBLogger
+    import physbiblio.gui.resourcesPyside2
+    from physbiblio.config import configuration_params, pbConfig
     from physbiblio.database import pBDB
-    from physbiblio.webimport.webInterf import physBiblioWeb
-    from physbiblio.gui.errorManager import pBGUILogger
+    from physbiblio.errors import pBLogger
     from physbiblio.gui.basicDialogs import (
         askDirName,
         askFileNames,
@@ -35,7 +35,9 @@ try:
         askYesNo,
         infoMessage,
     )
+    from physbiblio.gui.catWindows import CatsTreeWindow
     from physbiblio.gui.commonClasses import (
+        ObjListWindow,
         PBComboBox,
         PBDDTableWidget,
         PBDialog,
@@ -44,11 +46,10 @@ try:
         PBLabelRight,
         PBTableView,
         PBTrueFalseCombo,
-        ObjListWindow,
     )
-    from physbiblio.gui.catWindows import CatsTreeWindow
-    import physbiblio.gui.resourcesPyside2
+    from physbiblio.gui.errorManager import pBGUILogger
     from physbiblio.strings.gui import DialogWindowsStrings as dwstr
+    from physbiblio.webimport.webInterf import physBiblioWeb
 except ImportError:
     print("Could not find physbiblio and its modules!")
     print(traceback.format_exc())
@@ -194,7 +195,9 @@ class ConfigWindow(PBDialog):
         """
         ix = pbConfig.paramOrder.index("pdfFolder")
         folder = askDirName(
-            parent=None, dir=self.textValues[ix][1].text(), title=dwstr.dirPDFSave,
+            parent=None,
+            dir=self.textValues[ix][1].text(),
+            title=dwstr.dirPDFSave,
         )
         if folder.strip() != "":
             self.textValues[ix][1].setText(str(folder))
@@ -960,14 +963,20 @@ class ExportForTexDialog(PBDialog):
     def onAskBib(self):
         """Accept the output (set self.result to True and close)"""
         outFName = askSaveFileName(
-            self, title=dwstr.whereExportBibs, filter="Bibtex (*.bib)",
+            self,
+            title=dwstr.whereExportBibs,
+            filter="Bibtex (*.bib)",
         )
         if outFName != "":
             self.bibButton.setText(outFName)
 
     def onAskTex(self, ix):
         """Accept the output (set self.result to True and close)"""
-        texFile = askFileNames(self, title=dwstr.whichTexFiles, filter="Latex (*.tex)",)
+        texFile = askFileNames(
+            self,
+            title=dwstr.whichTexFiles,
+            filter="Latex (*.tex)",
+        )
         if texFile != "" and texFile != []:
             self.texButtons[ix].setText("%s" % texFile)
 
