@@ -2,20 +2,15 @@
 
 This file is part of the physbiblio package.
 """
-import sys
-import traceback
-import os
-import six
-import signal
 import ast
 import glob
+import os
+import signal
+import sys
+import traceback
+
 import bibtexparser
-
-if sys.version_info[0] < 3:
-    from Queue import Queue
-else:
-    from queue import Queue
-
+import six
 from PySide2.QtCore import Qt, Signal
 from PySide2.QtGui import QIcon, QPixmap
 from PySide2.QtWidgets import (
@@ -32,72 +27,78 @@ from PySide2.QtWidgets import (
     QWidget,
 )
 
+if sys.version_info[0] < 3:
+    from Queue import Queue
+else:
+    from queue import Queue
+
+
 try:
-    from physbiblio.errors import pBErrorManager, pBLogger
-    from physbiblio.database import pBDB, dbStats
-    from physbiblio.export import pBExport
-    from physbiblio.webimport.webInterf import physBiblioWeb
-    from physbiblio.config import configuration_params, pbConfig
-    from physbiblio.pdf import pBPDF
-    from physbiblio.view import pBView
     from physbiblio.bibtexWriter import pbWriter
-    from physbiblio.inspireStats import pBStats
-    from physbiblio.gui.errorManager import pBGUILogger
+    from physbiblio.config import configuration_params, pbConfig
+    from physbiblio.database import dbStats, pBDB
+    from physbiblio.errors import pBErrorManager, pBLogger
+    from physbiblio.export import pBExport
     from physbiblio.gui.basicDialogs import (
+        LongInfoMessage,
         askFileName,
         askFileNames,
         askGenericText,
         askSaveFileName,
         askYesNo,
         infoMessage,
-        LongInfoMessage,
     )
-    from physbiblio.gui.commonClasses import ObjectWithSignal, PBComboBox, WriteStream
     from physbiblio.gui.bibWindows import (
         AbstractFormulas,
+        BibtexInfo,
+        BibtexListWindow,
         FieldsFromArxiv,
         SearchBibsWindow,
         editBibtex,
-        BibtexListWindow,
-        BibtexInfo,
     )
     from physbiblio.gui.catWindows import CatsTreeWindow, editCategory
+    from physbiblio.gui.commonClasses import ObjectWithSignal, PBComboBox, WriteStream
     from physbiblio.gui.dialogWindows import (
-        ConfigWindow,
-        LogFileContentDialog,
-        PrintText,
         AdvancedImportDialog,
         AdvancedImportSelect,
+        ConfigWindow,
         DailyArxivDialog,
         DailyArxivSelect,
         ExportForTexDialog,
+        LogFileContentDialog,
+        PrintText,
     )
+    from physbiblio.gui.errorManager import pBGUILogger
     from physbiblio.gui.expWindows import (
-        editExperiment,
-        ExpsListWindow,
         EditExperimentDialog,
+        ExpsListWindow,
+        editExperiment,
     )
     from physbiblio.gui.inspireStatsGUI import AuthorStatsPlots, PaperStatsPlots
     from physbiblio.gui.profilesManager import SelectProfiles, editProfile
     from physbiblio.gui.threadElements import (
         Thread_authorStats,
+        Thread_checkUpdated,
+        Thread_cleanAllBibtexs,
         Thread_cleanSpare,
         Thread_cleanSparePDF,
-        Thread_updateAllBibtexs,
         Thread_exportTexBib,
-        Thread_importFromBib,
-        Thread_updateInspireInfo,
-        Thread_paperStats,
-        Thread_loadAndInsert,
-        Thread_cleanAllBibtexs,
-        Thread_findBadBibtexs,
         Thread_fieldsArxiv,
-        Thread_checkUpdated,
-        Thread_replace,
+        Thread_findBadBibtexs,
         Thread_importDailyArxiv,
+        Thread_importFromBib,
+        Thread_loadAndInsert,
+        Thread_paperStats,
+        Thread_replace,
+        Thread_updateAllBibtexs,
+        Thread_updateInspireInfo,
     )
-    from physbiblio.strings.main import DatabaseStrings as dbstr
+    from physbiblio.inspireStats import pBStats
+    from physbiblio.pdf import pBPDF
     from physbiblio.strings.gui import MainWindowStrings as mwstr
+    from physbiblio.strings.main import DatabaseStrings as dbstr
+    from physbiblio.view import pBView
+    from physbiblio.webimport.webInterf import physBiblioWeb
 except ImportError as e:
     print("Could not find physbiblio and its modules!", e)
     print(traceback.format_exc())
@@ -238,7 +239,10 @@ class MainWindow(QMainWindow):
         by another instance of the program.
         Ask what to do and close the main window.
         """
-        if askYesNo(mwstr.dbLockedAskClose, title=mwstr.attentionE,):
+        if askYesNo(
+            mwstr.dbLockedAskClose,
+            title=mwstr.attentionE,
+        ):
             raise SystemExit
 
     def setIcon(self):
@@ -539,7 +543,10 @@ class MainWindow(QMainWindow):
         )
 
         self.cleanSpareAct = QAction(
-            mwstr.Act.cleET, self, statusTip=mwstr.Act.cleED, triggered=self.cleanSpare,
+            mwstr.Act.cleET,
+            self,
+            statusTip=mwstr.Act.cleED,
+            triggered=self.cleanSpare,
         )
 
         self.cleanSparePDFAct = QAction(
@@ -786,7 +793,7 @@ class MainWindow(QMainWindow):
 
     def currentTabWidget(self):
         """Return the current BibtexListWindow in the self.tabWidget
-        
+
         Output:
             a BibtexListWindow item, currently displayed in the QTabWidget
         """
@@ -1138,7 +1145,9 @@ class MainWindow(QMainWindow):
     def export(self):
         """Ask and export the last database query result in a .bib file"""
         filename = askSaveFileName(
-            self, title=mwstr.exportWhereG, filter="Bibtex (*.bib)",
+            self,
+            title=mwstr.exportWhereG,
+            filter="Bibtex (*.bib)",
         )
         if filename != "":
             pBExport.exportLast(filename)
@@ -1153,7 +1162,9 @@ class MainWindow(QMainWindow):
             entries: the list of entries to be exported
         """
         filename = askSaveFileName(
-            self, title=mwstr.exportWhereS, filter="Bibtex (*.bib)",
+            self,
+            title=mwstr.exportWhereS,
+            filter="Bibtex (*.bib)",
         )
         if filename != "":
             pBExport.exportSelected(filename, entries)
@@ -1211,7 +1222,9 @@ class MainWindow(QMainWindow):
     def exportAll(self):
         """Ask and export all the entries in a .bib file"""
         filename = askSaveFileName(
-            self, title=mwstr.exportWhereG, filter="Bibtex (*.bib)",
+            self,
+            title=mwstr.exportWhereG,
+            filter="Bibtex (*.bib)",
         )
         if filename != "":
             pBExport.exportAll(filename)
@@ -1271,7 +1284,9 @@ class MainWindow(QMainWindow):
                     cancel = False
                     while name.strip() == "":
                         res = askGenericText(
-                            mwstr.replaceAskName, mwstr.replaceName, parent=self,
+                            mwstr.replaceAskName,
+                            mwstr.replaceName,
+                            parent=self,
                         )
                         if res[1]:
                             name = res[0]
@@ -1310,7 +1325,9 @@ class MainWindow(QMainWindow):
                 cancel = False
                 while name.strip() == "":
                     res = askGenericText(
-                        mwstr.searchAskName, mwstr.searchName, parent=self,
+                        mwstr.searchAskName,
+                        mwstr.searchName,
+                        parent=self,
                     )
                     if res[1]:
                         name = res[0]
@@ -1509,8 +1526,15 @@ class MainWindow(QMainWindow):
         """Same as updateAllBibtexs, but ask the values of
         `startFrom` and `force` before the execution
         """
-        force = askYesNo(mwstr.forceUpdText, mwstr.forceUpdTitle,)
-        text, out = askGenericText(mwstr.updINumText, mwstr.updINumTitle, self,)
+        force = askYesNo(
+            mwstr.forceUpdText,
+            mwstr.forceUpdTitle,
+        )
+        text, out = askGenericText(
+            mwstr.updINumText,
+            mwstr.updINumTitle,
+            self,
+        )
         if not out:
             return
         try:
@@ -1584,7 +1608,9 @@ class MainWindow(QMainWindow):
         for one or more authors using the INSPIRE-HEP database
         """
         authorName, out = askGenericText(
-            mwstr.authorStNameAsk, mwstr.authorStNameTit, self,
+            mwstr.authorStNameAsk,
+            mwstr.authorStNameTit,
+            self,
         )
         if not out:
             return False
@@ -1656,7 +1682,11 @@ class MainWindow(QMainWindow):
             doReload (default True): if True, reload
                 the main entries list at the end
         """
-        queryStr, out = askGenericText(mwstr.importInspAskStr, mwstr.queryStr, self,)
+        queryStr, out = askGenericText(
+            mwstr.importInspAskStr,
+            mwstr.queryStr,
+            self,
+        )
         if not out:
             return False
         if queryStr == "":
@@ -1797,10 +1827,13 @@ class MainWindow(QMainWindow):
                     db.entries = [el["bibpars"]]
                     entry = pbWriter.write(db)
                     data = pBDB.bibs.prepareInsert(entry)
+                    if data == {"bibkey": ""}:
+                        pBGUILogger.warning(mwstr.elementFailedBibtex % key)
+                        continue
                     if method == "adsnasa":
                         data["ads"] = key
                     if not pBDB.bibs.insert(data):
-                        pBLogger.warning(mwstr.elementFailed % key)
+                        pBGUILogger.warning(mwstr.elementFailed % key)
                         continue
                     try:
                         if method == "inspire":
@@ -1826,13 +1859,20 @@ class MainWindow(QMainWindow):
         Ask the index of the entry where to start from,
         before proceeding
         """
-        text, out = askGenericText(mwstr.cleBibStartAsk, mwstr.cleBibStartTit, self,)
+        text, out = askGenericText(
+            mwstr.cleBibStartAsk,
+            mwstr.cleBibStartTit,
+            self,
+        )
         if not out:
             return
         try:
             startFrom = int(text)
         except ValueError:
-            if askYesNo(mwstr.invalidIntAsk, mwstr.invalidEntry,):
+            if askYesNo(
+                mwstr.invalidIntAsk,
+                mwstr.invalidEntry,
+            ):
                 startFrom = 0
             else:
                 return
@@ -1992,7 +2032,10 @@ class MainWindow(QMainWindow):
         while (
             not isinstance(pbConfig.params["ADSToken"], six.string_types)
         ) or pbConfig.params["ADSToken"].strip() == "":
-            newkey, out = askGenericText(mwstr.askADSTokenText, mwstr.askADSTokenTitle,)
+            newkey, out = askGenericText(
+                mwstr.askADSTokenText,
+                mwstr.askADSTokenTitle,
+            )
             if not out:
                 return False
             if newkey.strip() != "":
