@@ -3,27 +3,28 @@
 
 This file is part of the physbiblio package.
 """
+import os
 import sys
 import traceback
-import os
-from PySide2.QtCore import Qt, QEvent, QModelIndex, QPoint, QRect
+
+from PySide2.QtCore import QEvent, QModelIndex, QPoint, QRect, Qt
 from PySide2.QtTest import QTest
 from PySide2.QtWidgets import QWidget
 
 if sys.version_info[0] < 3:
     import unittest2 as unittest
-    from mock import patch, call, MagicMock
+    from mock import MagicMock, call, patch
 else:
     import unittest
-    from unittest.mock import patch, call, MagicMock
+    from unittest.mock import MagicMock, call, patch
 
 try:
-    from physbiblio.setuptests import *
+    from physbiblio.config import configuration_params, pbConfig
     from physbiblio.database import pBDB
-    from physbiblio.config import pbConfig, configuration_params
-    from physbiblio.gui.setuptests import *
-    from physbiblio.gui.dialogWindows import *
     from physbiblio.gui.bibWindows import AbstractFormulas
+    from physbiblio.gui.dialogWindows import *
+    from physbiblio.gui.setuptests import *
+    from physbiblio.setuptests import *
 except ImportError:
     print("Could not find physbiblio and its modules!")
     print(traceback.format_exc())
