@@ -3,27 +3,28 @@
 
 This file is part of the physbiblio package.
 """
+import os
 import sys
 import traceback
-import os
-from PySide2.QtCore import Qt, QEvent, QModelIndex
-from PySide2.QtTest import QTest
+
+from PySide2.QtCore import QEvent, QModelIndex, Qt
 from PySide2.QtGui import QMouseEvent
+from PySide2.QtTest import QTest
 from PySide2.QtWidgets import QWidget
 
 if sys.version_info[0] < 3:
     import unittest2 as unittest
-    from mock import patch, call, MagicMock
+    from mock import MagicMock, call, patch
 else:
     import unittest
-    from unittest.mock import patch, call, MagicMock
+    from unittest.mock import MagicMock, call, patch
 
 try:
-    from physbiblio.setuptests import *
-    from physbiblio.gui.setuptests import *
     from physbiblio.gui.commonClasses import PBTableView
     from physbiblio.gui.expWindows import *
     from physbiblio.gui.mainWindow import MainWindow
+    from physbiblio.gui.setuptests import *
+    from physbiblio.setuptests import *
 except ImportError:
     print("Could not find physbiblio and its modules!")
     raise
@@ -1131,10 +1132,10 @@ class TestExpsListWindow(GUITestCase):
         ) as _ol, patch("logging.Logger.debug") as _l:
             self.assertEqual(elw.cellDoubleClick(elw.proxyModel.index(1, 4)), True)
             _ol.assert_called_once_with(
-                pBGuiView, pbConfig.inspireRecord + "1234", "link"
+                pBGuiView, pbConfig.inspireExperimentsLink + "1234", "link"
             )
             _l.assert_called_once_with(
-                "Opening '%s'..." % (pbConfig.inspireRecord + "1234")
+                "Opening '%s'..." % (pbConfig.inspireExperimentsLink + "1234")
             )
         with patch(
             "physbiblio.gui.commonClasses.GUIViewEntry.openLink",
@@ -1145,13 +1146,14 @@ class TestExpsListWindow(GUITestCase):
         ) as _w:
             self.assertEqual(elw.cellDoubleClick(elw.proxyModel.index(1, 4)), True)
             _ol.assert_called_once_with(
-                pBGuiView, pbConfig.inspireRecord + "1234", "link"
+                pBGuiView, pbConfig.inspireExperimentsLink + "1234", "link"
             )
             _l.assert_called_once_with(
-                "Opening '%s'..." % (pbConfig.inspireRecord + "1234")
+                "Opening '%s'..." % (pbConfig.inspireExperimentsLink + "1234")
             )
             _w.assert_called_once_with(
-                "Opening link '%s' failed!" % (pbConfig.inspireRecord + "1234"),
+                "Opening link '%s' failed!"
+                % (pbConfig.inspireExperimentsLink + "1234"),
                 exc_info=True,
             )
 
