@@ -3,27 +3,29 @@
 This file is part of the physbiblio package.
 """
 import sys
-import traceback
 import time
-from PySide2.QtCore import Signal
+import traceback
+
+import bibtexparser
 from outdated import check_outdated
+from PySide2.QtCore import Signal
+from requests.exceptions import ConnectionError
 
 if sys.version_info[0] < 3:
     from urllib2 import URLError
 else:
     from urllib.request import URLError
-from requests.exceptions import ConnectionError
-import bibtexparser
+
 
 try:
     from physbiblio import __version__
-    from physbiblio.errors import pBLogger
     from physbiblio.bibtexWriter import pbWriter
     from physbiblio.database import pBDB
-    from physbiblio.pdf import pBPDF
-    from physbiblio.inspireStats import pBStats
+    from physbiblio.errors import pBLogger
     from physbiblio.export import pBExport
     from physbiblio.gui.commonClasses import PBThread, WriteStream
+    from physbiblio.inspireStats import pBStats
+    from physbiblio.pdf import pBPDF
     from physbiblio.strings.gui import ThreadElementsStrings as thestr
 except ImportError:
     print("Could not find physbiblio and its modules!")
@@ -46,11 +48,13 @@ class Thread_checkUpdated(PBThread):
             self.result.emit(outdated, newVersion)
         except ValueError:
             pBLogger.warning(
-                thestr.outdatedError, exc_info=True,
+                thestr.outdatedError,
+                exc_info=True,
             )
         except (URLError, ConnectionError):
             pBLogger.warning(
-                thestr.outdatedWarning, exc_info=True,
+                thestr.outdatedWarning,
+                exc_info=True,
             )
 
 
@@ -745,7 +749,10 @@ class Thread_importDailyArxiv(PBThread):
                 continue
             el = self.found[key]
             if pBDB.bibs.loadAndInsert(el["bibpars"]["eprint"]):
-                newKey = pBDB.bibs.getByKey(key)[0]["bibkey"]
+                try:
+                    newKey = pBDB.bibs.getByKey(key)[0]["bibkey"]
+                except IndexError:
+                    newKey = pBDB.bibs.getByBibtex(key)[0]["bibkey"]
                 inserted.append(newKey)
             else:
                 db.entries = [
