@@ -3,10 +3,14 @@
 
 This file is part of the physbiblio package.
 """
-import sys
 import datetime
-import traceback
 import os
+import sys
+import traceback
+
+import requests
+from requests.adapters import HTTPAdapter
+from requests.packages.urllib3.util.retry import Retry
 
 if sys.version_info[0] < 3:
     import unittest2 as unittest
@@ -14,10 +18,11 @@ else:
     import unittest
 
 try:
-    from physbiblio.setuptests import *
-    from physbiblio.webimport.webInterf import physBiblioWeb
-    from physbiblio.webimport.inspireoai import get_journal_ref_xml
     from physbiblio.config import pbConfig
+    from physbiblio.parseAccents import parse_accents_str
+    from physbiblio.setuptests import *
+    from physbiblio.webimport.inspireoai import get_journal_ref_xml
+    from physbiblio.webimport.webInterf import PBSession, WebInterf, physBiblioWeb
 except ImportError:
     print("Could not find physbiblio and its modules!")
     raise
@@ -33,6 +38,7 @@ class TestWebImportMethods(unittest.TestCase):
 
     def test_methods_success(self):
         """Test webimport with known results"""
+        self.maxDiff = None
         tests = {
             "arxiv": [
                 "1507.08204",
@@ -78,19 +84,16 @@ class TestWebImportMethods(unittest.TestCase):
             "inspire": [
                 "Gariazzo:2015rra",
                 """@article{Gariazzo:2015rra,
-      author         = "Gariazzo, S. and Giunti, C. """
-                + """and Laveder, M. and Li, Y. F.
-                        and Zavanin, E. M.",
-      title          = "{Light sterile neutrinos}",
-      journal        = "J. Phys.",
-      volume         = "G43",
-      year           = "2016",
-      pages          = "033001",
-      doi            = "10.1088/0954-3899/43/3/033001",
-      eprint         = "1507.08204",
-      archivePrefix  = "arXiv",
-      primaryClass   = "hep-ph",
-      SLACcitation   = "%%CITATION = ARXIV:1507.08204;%%"
+    author = "Gariazzo, S. and Giunti, C. and Laveder, M. and Li, Y.F. and Zavanin, E.M.",
+    title = "{Light sterile neutrinos}",
+    eprint = "1507.08204",
+    archivePrefix = "arXiv",
+    primaryClass = "hep-ph",
+    doi = "10.1088/0954-3899/43/3/033001",
+    journal = "J. Phys. G",
+    volume = "43",
+    pages = "033001",
+    year = "2016"
 }""",
             ],
             "inspireoai": [
@@ -414,6 +417,76 @@ class TestWebImportMethods(unittest.TestCase):
 class TestWebImportOffline(unittest.TestCase):
     """Offline test for some functions of the webImport package."""
 
+    def test_PBSession(self):
+        """test the PBSession class"""
+        pbs = PBSession()
+        self.assertIsInstance(pbs, requests.Session)
+        fr = Retry()
+        ha = HTTPAdapter(max_retries=fr)
+        with patch(
+            "physbiblio.webimport.webInterf.Retry", return_value=fr
+        ) as _r, patch(
+            "physbiblio.webimport.webInterf.HTTPAdapter", return_value=ha
+        ) as _ha, patch(
+            "requests.Session.mount"
+        ) as _m:
+            pbs = PBSession()
+            _r.assert_called_once_with(
+                total=5,
+                backoff_factor=1.0,
+                status_forcelist=[429, 500, 502, 503, 504],
+                method_whitelist=["HEAD", "GET", "OPTIONS"],
+            )
+            _ha.assert_called_once_with(max_retries=fr)
+            _m.assert_any_call("https://", ha)
+            _m.assert_any_call("http://", ha)
+
+    def test_createUrl(self):
+        """Test createUrl"""
+        pbw = WebInterf()
+        pbw.url = pbConfig.inspireLiteratureAPI
+        pbw.urlArgs = {"abc": "1", "def": "2"}
+        self.assertEqual(
+            pbw.createUrl(), "https://inspirehep.net/api/literature/?abc=1&def=2"
+        )
+        self.assertEqual(
+            pbw.createUrl({"abc": "2", "def": "1"}),
+            "https://inspirehep.net/api/literature/?abc=2&def=1",
+        )
+        self.assertEqual(
+            pbw.createUrl({}),
+            "https://inspirehep.net/api/literature/",
+        )
+        self.assertEqual(
+            pbw.createUrl({}, ""),
+            "https://inspirehep.net/api/literature/",
+        )
+        self.assertEqual(
+            pbw.createUrl({"def": "1"}, "abc"),
+            "abc?def=1",
+        )
+
+    def test_inspire_retrieve(self):
+        """Test retrieveUrlFirst and retrieveUrlAll from inspire module"""
+        with patch(
+            "physbiblio.webimport.inspire.WebSearch.retrieveBibtex",
+            autospec=True,
+            side_effect=["abc", "def"],
+        ) as _f:
+            self.assertEqual(
+                physBiblioWeb.webSearch["inspire"].retrieveUrlFirst("abc"), "abc"
+            )
+            _f.assert_called_once_with(
+                physBiblioWeb.webSearch["inspire"], "abc", size=1
+            )
+            _f.reset_mock()
+            self.assertEqual(
+                physBiblioWeb.webSearch["inspire"].retrieveUrlAll("abc"), "def"
+            )
+            _f.assert_called_once_with(
+                physBiblioWeb.webSearch["inspire"], "abc", size=250
+            )
+
     def test_arxivYear(self):
         """test the arxivDaily method in the arxiv module"""
         self.assertEqual(physBiblioWeb.webSearch["arxiv"].getYear("abc"), None)
